Documentation
¶
Overview ¶
Package rest contains the types and interfaces to interact with the Liqo API.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func OutputJSON ¶ added in v0.10.2
OutputJSON prints the given object in JSON format with indentation.
func OutputYAML ¶ added in v0.10.2
OutputYAML prints the given object in YAML format.
Types ¶
type API ¶
type API interface {
APIOptions() *APIOptions
Create(ctx context.Context, options *CreateOptions) *cobra.Command
Delete(ctx context.Context, options *DeleteOptions) *cobra.Command
Get(ctx context.Context, options *GetOptions) *cobra.Command
Update(ctx context.Context, options *UpdateOptions) *cobra.Command
Generate(ctx context.Context, options *GenerateOptions) *cobra.Command
}
API is the interface that must be implemented by the API.
type APIOptions ¶
type APIOptions struct {
EnableCreate bool
EnableDelete bool
EnableGet bool
EnableUpdate bool
EnableGenerate bool
}
APIOptions contains the options for the API.
type CreateOptions ¶
CreateOptions contains the options for the create API.
type DeleteOptions ¶
DeleteOptions contains the options for the delete API.
type GenerateOptions ¶ added in v1.0.0
GenerateOptions contains the options for the generate API.
type GetOptions ¶
GetOptions contains the options for the get API.
type UpdateOptions ¶
UpdateOptions contains the options for the update API.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package configuration contains the logic to manage the network configuration.
|
Package configuration contains the logic to manage the network configuration. |
|
Package gatewayclient contains the logic to manage GatewayClients.
|
Package gatewayclient contains the logic to manage GatewayClients. |
|
Package gatewayserver contains the logic to manage GatewayServers.
|
Package gatewayserver contains the logic to manage GatewayServers. |
|
Package identity contains the rest API commands to allow liqoctl to interact with Identity resources.
|
Package identity contains the rest API commands to allow liqoctl to interact with Identity resources. |
|
Package kubeconfig contains the rest API commands to allow liqoctl to interact with kubeconfigs.
|
Package kubeconfig contains the rest API commands to allow liqoctl to interact with kubeconfigs. |
|
Package nonce contains the rest API commands to allow liqoctl to interact with the Nonces.
|
Package nonce contains the rest API commands to allow liqoctl to interact with the Nonces. |
|
Package peeringuser contains the rest API commands to allow liqoctl to create an authentication token to authenticate to this cluster.
|
Package peeringuser contains the rest API commands to allow liqoctl to create an authentication token to authenticate to this cluster. |
|
userfactory
Package userfactory contains the logic to create a new user for the peering.
|
Package userfactory contains the logic to create a new user for the peering. |
|
Package publickey contains the logic to manage PublicKeys.
|
Package publickey contains the logic to manage PublicKeys. |
|
Package resourceslice contains the rest API commands to allow liqoctl to interact with ResourceSlice resources.
|
Package resourceslice contains the rest API commands to allow liqoctl to interact with ResourceSlice resources. |
|
Package tenant contains the rest API commands to allow liqoctl to interact with Tenant resources.
|
Package tenant contains the rest API commands to allow liqoctl to interact with Tenant resources. |
|
Package virtualnode contains the rest API commands to allow liqoctl to interact with the VirtualNodes.
|
Package virtualnode contains the rest API commands to allow liqoctl to interact with the VirtualNodes. |
Click to show internal directories.
Click to hide internal directories.